@@ -71,6 +71,7 @@ from specfact_cli.commands import (
     sdd,
     spec,
     sync,
+    update,
     validate,
 )
 from specfact_cli.modes import OperationalMode, detect_mode
@@ -133,8 +134,8 @@ console = get_configured_console()
 # Global mode context (set by --mode flag or auto-detected)
 _current_mode: OperationalMode | None = None
 
-# Global banner flag (set by --no-banner flag)
-_show_banner: bool = True
+# Global banner flag (set by --banner flag)
+_show_banner: bool = False
 
 
 def print_banner() -> None:
@@ -178,6 +179,11 @@ def print_banner() -> None:
             console.print()  # Empty line
 
 
+def print_version_line() -> None:
+    """Print simple version line like other CLIs."""
+    console.print(f"[dim]SpecFact CLI - v{__version__}[/dim]")
+
+
 def version_callback(value: bool) -> None:
     """Show version information."""
     if value:
@@ -226,10 +232,10 @@ def main(
         is_eager=True,
         help="Show version and exit",
     ),
-    no_banner: bool = typer.Option(
+    banner: bool = typer.Option(
         False,
-        "--no-banner",
-        help="Hide ASCII art banner (useful for CI/CD)",
+        "--banner",
+        help="Show ASCII art banner (hidden by default, shown on first run)",
     ),
     mode: str | None = typer.Option(
         None,
@@ -242,6 +248,11 @@ def main(
         "--debug",
         help="Enable debug output (shows detailed logging and diagnostic information)",
     ),
+    skip_checks: bool = typer.Option(
+        False,
+        "--skip-checks",
+        help="Skip startup checks (template validation and version check) - useful for CI/CD",
+    ),
     input_format: Annotated[
         StructuredFormat,
         typer.Option(
@@ -281,8 +292,8 @@ def main(
     - Default to CI/CD mode
     """
     global _show_banner
-    # Set banner flag based on --no-banner option
-    _show_banner = not no_banner
+    # Set banner flag based on --banner option
+    _show_banner = banner
 
     # Set debug mode
     set_debug_mode(debug)
@@ -372,6 +383,7 @@ app.add_typer(drift.app, name="drift", help="Detect drift between code and speci
 # 11.6. Analysis
 app.add_typer(analyze.app, name="analyze", help="Analyze codebase for contract coverage and quality")
 app.add_typer(validate.app, name="validate", help="Validation commands including sidecar validation")
+app.add_typer(update.app, name="upgrade", help="Check for and install SpecFact CLI updates")
 
 
 def cli_main() -> None:
@@ -384,12 +396,19 @@ def cli_main() -> None:
     # Normalize shell names in argv for Typer's built-in completion commands
     normalize_shell_in_argv()
 
-    # Check if --no-banner flag is present (before Typer processes it)
-    no_banner_requested = "--no-banner" in sys.argv
+    # Check if --banner flag is present (before Typer processes it)
+    banner_requested = "--banner" in sys.argv
 
-    # Show banner by default unless --no-banner is specified
-    # Banner shows for: no args, --help/-h, or any command (unless --no-banner)
-    show_banner = not no_banner_requested
+    # Check if this is first run (no ~/.specfact folder exists)
+    # Use Path.home() directly to avoid importing metadata module (which creates the directory)
+    specfact_dir = Path.home() / ".specfact"
+    is_first_run = not specfact_dir.exists()
+
+    # Show banner if:
+    # 1. --banner flag is explicitly requested, OR
+    # 2. This is the first run (no ~/.specfact folder exists)
+    # Otherwise, show simple version line
+    show_banner = banner_requested or is_first_run
 
     # Intercept Typer's shell detection for --show-completion and --install-completion
     # when no shell is provided (auto-detection case)
@@ -421,11 +440,19 @@ def cli_main() -> None:
             else:
                 os.environ["_SPECFACT_COMPLETE"] = mapped_shell
 
-    # Show banner by default (unless --no-banner is specified)
-    # Only show once, before Typer processes the command
+    # Show banner or version line before Typer processes the command
+    # Skip for help/version/completion commands and in test mode to avoid cluttering output
+    skip_output_commands = ("--help", "-h", "--version", "-v", "--show-completion", "--install-completion")
+    is_help_or_version = any(arg in skip_output_commands for arg in sys.argv[1:])
+    # Check test mode using same pattern as terminal.py
+    is_test_mode = os.environ.get("TEST_MODE") == "true" or os.environ.get("PYTEST_CURRENT_TEST") is not None
+
     if show_banner:
         print_banner()
         console.print()  # Empty line after banner
+    elif not is_help_or_version and not is_test_mode:
+        # Show simple version line like other CLIs (skip for help/version commands and in test mode)
+        print_version_line()
 
     # Run startup checks (template validation and version check)
     # Only run for actual commands, not for help/version/completion
@@ -450,8 +477,11 @@ def cli_main() -> None:
         # Run checks (version check may be slow, so we do it async or with timeout)
         import contextlib
 
+        # Check if --skip-checks flag is present
+        skip_checks_flag = "--skip-checks" in sys.argv
+
         with contextlib.suppress(Exception):
-            print_startup_checks(repo_path=repo_path, check_version=True)
+            print_startup_checks(repo_path=repo_path, check_version=True, skip_checks=skip_checks_flag)
 
     # Record start time for command execution
     start_time = datetime.now()
