@@ -121,6 +121,8 @@ SPECFACT_COMMANDS = [
     "specfact.06-sync",
     "specfact.07-contracts",
     "specfact.compare",
+    "specfact.sync-backlog",
+    "specfact.backlog-refine",
     "specfact.validate",
 ]
 
